summaryrefslogtreecommitdiffstats
path: root/win/CS/HandBrake.ApplicationServices
diff options
context:
space:
mode:
authorhandbrake <[email protected]>2013-01-31 08:18:55 +0000
committerhandbrake <[email protected]>2013-01-31 08:18:55 +0000
commitbc3b56381c6ac214b7736a00972c9d0902902453 (patch)
tree6caffbe88ef2ee5efbd2279cf00556a986a7c22e /win/CS/HandBrake.ApplicationServices
parent39821495c82b104b77e628d5cb244be041e285ed (diff)
add a new compile option: --enable-hwd
change the GUI uvd checkbox's name to hardware decoder modify the issue compile on linux modify the issue on Intel platform with Intel integrate graphic add a new opencl scale algorithm, PSNR goes up (added files: scale.h, scale.c, scale_kernel.h, scale_kernel.c) merge the cropscaleaccl.c to cropscale.c merge the decavcodecaccl.c to decavcodec.c git-svn-id: svn://svn.handbrake.fr/HandBrake/branches/opencl@5227 b64f7644-9d1e-0410-96f1-a4d463321fa5
Diffstat (limited to 'win/CS/HandBrake.ApplicationServices')
-rw-r--r--win/CS/HandBrake.ApplicationServices/Model/EncodeTask.cs6
-rw-r--r--win/CS/HandBrake.ApplicationServices/Parsing/Title.cs12
-rw-r--r--win/CS/HandBrake.ApplicationServices/Utilities/InteropModelCreator.cs2
-rw-r--r--win/CS/HandBrake.ApplicationServices/Utilities/PlistUtility.cs2
-rw-r--r--win/CS/HandBrake.ApplicationServices/Utilities/QueryGeneratorUtility.cs2
-rw-r--r--win/CS/HandBrake.ApplicationServices/Utilities/QueryParserUtility.cs4
6 files changed, 14 insertions, 14 deletions
diff --git a/win/CS/HandBrake.ApplicationServices/Utilities/InteropModelCreator.cs b/win/CS/HandBrake.ApplicationServices/Utilities/InteropModelCreator.cs
index 5cb0d4768..618dd43cc 100644
--- a/win/CS/HandBrake.ApplicationServices/Utilities/InteropModelCreator.cs
+++ b/win/CS/HandBrake.ApplicationServices/Utilities/InteropModelCreator.cs
@@ -102,7 +102,7 @@ namespace HandBrake.ApplicationServices.Utilities
profile.Height = work.Height.HasValue ? work.Height.Value : 0;
profile.IPod5GSupport = work.IPod5GSupport;
profile.OpenCLGSupport = work.OpenCLSupport;
- profile.UVDSupport = work.UVDSupport;
+ profile.HWDSupport = work.HWDSupport;
profile.IncludeChapterMarkers = work.IncludeChapterMarkers;
profile.KeepDisplayAspect = work.KeepDisplayAspect;
profile.LargeFile = work.LargeFile;
diff --git a/win/CS/HandBrake.ApplicationServices/Utilities/PlistUtility.cs b/win/CS/HandBrake.ApplicationServices/Utilities/PlistUtility.cs
index 260abfe54..e22345134 100644
--- a/win/CS/HandBrake.ApplicationServices/Utilities/PlistUtility.cs
+++ b/win/CS/HandBrake.ApplicationServices/Utilities/PlistUtility.cs
@@ -142,7 +142,7 @@ namespace HandBrake.ApplicationServices.Utilities
AddEncodeElement(xmlWriter, "Mp4LargeFile", "integer", parsed.LargeFile ? "1" : "0");
AddEncodeElement(xmlWriter, "Mp4iPodCompatible", "integer", parsed.IPod5GSupport ? "1" : "0");
AddEncodeElement(xmlWriter, "OpenCLSupport", "integer", parsed.OpenCLSupport ? "1" : "0");
- AddEncodeElement(xmlWriter, "UVDSupport", "integer", parsed.UVDSupport ? "1" : "0");
+ AddEncodeElement(xmlWriter, "HWDSupport", "integer", parsed.HWDSupport ? "1" : "0");
AddEncodeElement(xmlWriter, "PictureAutoCrop", "integer", "1");
AddEncodeElement(xmlWriter, "PictureBottomCrop", "integer", parsed.Cropping.Bottom.ToString());
diff --git a/win/CS/HandBrake.ApplicationServices/Utilities/QueryGeneratorUtility.cs b/win/CS/HandBrake.ApplicationServices/Utilities/QueryGeneratorUtility.cs
index 69cbfc258..6cdf1d900 100644
--- a/win/CS/HandBrake.ApplicationServices/Utilities/QueryGeneratorUtility.cs
+++ b/win/CS/HandBrake.ApplicationServices/Utilities/QueryGeneratorUtility.cs
@@ -246,7 +246,7 @@ namespace HandBrake.ApplicationServices.Utilities
if (task.OpenCLSupport)
query += " -P ";
- if (task.UVDSupport)
+ if (task.HWDSupport)
query += " -U ";
return query;
diff --git a/win/CS/HandBrake.ApplicationServices/Utilities/QueryParserUtility.cs b/win/CS/HandBrake.ApplicationServices/Utilities/QueryParserUtility.cs
index a167801df..9655d6629 100644
--- a/win/CS/HandBrake.ApplicationServices/Utilities/QueryParserUtility.cs
+++ b/win/CS/HandBrake.ApplicationServices/Utilities/QueryParserUtility.cs
@@ -57,7 +57,7 @@ namespace HandBrake.ApplicationServices.Utilities
Match largerMp4 = Regex.Match(input, @" -4");
Match ipodAtom = Regex.Match(input, @" -I");
Match openclSupport = Regex.Match(input, @" -P");
- Match uvdSupport = Regex.Match(input, @" -U");
+ Match hwdSupport = Regex.Match(input, @" -U");
// Picture Settings Tab
Match width = Regex.Match(input, @"-w ([0-9]+)");
@@ -158,7 +158,7 @@ namespace HandBrake.ApplicationServices.Utilities
parsed.IPod5GSupport = ipodAtom.Success;
parsed.OptimizeMP4 = optimizeMP4.Success;
parsed.OpenCLSupport = openclSupport.Success;
- parsed.UVDSupport = uvdSupport.Success;
+ parsed.HWDSupport = hwdSupport.Success;
#endregion
diff --git a/win/CS/HandBrake.ApplicationServices/Model/EncodeTask.cs b/win/CS/HandBrake.ApplicationServices/Model/EncodeTask.cs
index 5c9f166e0..f9053a8bb 100644
--- a/win/CS/HandBrake.ApplicationServices/Model/EncodeTask.cs
+++ b/win/CS/HandBrake.ApplicationServices/Model/EncodeTask.cs
@@ -88,7 +88,7 @@ namespace HandBrake.ApplicationServices.Model
this.IncludeChapterMarkers = task.IncludeChapterMarkers;
this.IPod5GSupport = task.IPod5GSupport;
this.OpenCLSupport = task.OpenCLSupport;
- this.UVDSupport = task.UVDSupport;
+ this.HWDSupport = task.HWDSupport;
this.KeepDisplayAspect = task.KeepDisplayAspect;
this.LargeFile = task.LargeFile;
this.MaxHeight = task.MaxHeight;
@@ -197,9 +197,9 @@ namespace HandBrake.ApplicationServices.Model
public bool OpenCLSupport { get; set; }
/// <summary>
/// Gets or sets a value indicating whether UVDSupport.
/// </summary>
- public bool UVDSupport { get; set; }
+ public bool HWDSupport { get; set; }
#endregion
#region Picture
@@ -197,9 +197,9 @@ namespace HandBrake.ApplicationServices.Model
public bool OpenCLSupport { get; set; }
/// <summary>
- /// Gets or sets a value indicating whether UVDSupport.
+ /// Gets or sets a value indicating whether HWDSupport.
/// </summary>
diff --git a/win/CS/HandBrake.ApplicationServices/Parsing/Title.cs b/win/CS/HandBrake.ApplicationServices/Parsing/Title.cs
index 466a33aa1..00488eac8 100644
--- a/win/CS/HandBrake.ApplicationServices/Parsing/Title.cs
+++ b/win/CS/HandBrake.ApplicationServices/Parsing/Title.cs
@@ -121,9 +121,9 @@ namespace HandBrake.ApplicationServices.Parsing
public int OpenCLSupport { get; set; }
/// <summary>
/// Gets or sets the UVD
/// </summary>
- public int UVDSupport { get; set; }
+ public int HWDSupport { get; set; }
#endregion
/// <summary>
@@ -236,14 +236,14 @@ namespace HandBrake.ApplicationServices.Parsing
}
nextLine = output.ReadLine();
- m = Regex.Match(nextLine, @"^ \+ support uvd:");
+ m = Regex.Match(nextLine, @"^ \+ support hwd:");
if (m.Success)
{
- temp = nextLine.Replace("+ support uvd:", string.Empty).Trim();
+ temp = nextLine.Replace("+ support hwd:", string.Empty).Trim();
if (string.Compare(temp, "yes") == 0)
- thisTitle.UVDSupport = 1;
+ thisTitle.HWDSupport = 1;
else
- thisTitle.UVDSupport = 0;
+ thisTitle.HWDSupport = 0;
}
thisTitle.Chapters.AddRange(Chapter.ParseList(output));
@@ -121,9 +121,9 @@ namespace HandBrake.ApplicationServices.Parsing
public int OpenCLSupport { get; set; }
/// <summary>
- /// Gets or sets the UVD
+ /// Gets or sets the HWD
/// </summary>